<?php

namespace Drupal\pusher_api;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Site\Settings;
use Pusher\Pusher;

/**
 * Service description.
 */
class PusherApiMainService {

  /**
   * The pusher API.
   *
   * @var \Pusher\Pusher
   */
  protected $pusher;

  /**
   * The module API settings.
   *
   * @var array
   */
  protected $apiSettings;

  /**
   * The modules config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * Constructs a PusherApiMainService object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory.
   * @param \Drupal\Core\Site\Settings $settings
   *   The site settings.
   *
   * @throws \Pusher\PusherException
   */
  public function __construct(ConfigFactoryInterface $configFactory, Settings $settings) {
    $this->config = $configFactory->get('pusher_api.settings');
    $this->apiSettings = $this->getApiSettings($settings);
    $this->setupPusher();
  }

  /**
   * Trigger an event in pusher.
   *
   * @param string $event
   *   The event name.
   * @param array $data
   *   The message.
   * @param bool|string $channel
   *   The channel name or FALSE, then default will be used.
   *
   * @throws \Pusher\ApiErrorException
   * @throws \Pusher\PusherException
   */
  public function triggerEvent($event, array $data, $channel = FALSE) {
    if (!$channel) {
      $channel = ($this->config->get('pusher_api_channel')) ? $this->config->get('pusher_api_channel') : 'pusher_api';
    }

    $this->pusher->trigger($channel, $event, $data);
  }

  /**
   * Set up the Pusher object.
   *
   * @throws \Pusher\PusherException
   */
  protected function setupPusher() {
    $options = [
      'cluster' => $this->apiSettings['cluster'],
      'useTLS' => TRUE,
    ];

    $this->pusher = new Pusher($this->apiSettings['key'], $this->apiSettings['secret'], $this->apiSettings['app_id'], $options);
  }

  /**
   * Get the settings from the settings.php.
   *
   * @param \Drupal\Core\Site\Settings $settings
   *
   * @return array
   */
  protected function getApiSettings(Settings $settings) {
    $fullSettings = $settings::get('pusher_api');

    return $fullSettings['api_settings'];
  }

}
